import { BlockState } from './block';
import { Entity } from './entity';
import { useBridge, Pos, Identifier } from './core';

/**
 * World
 */
export class World {
    /**
     * @internal
     */
    javaObject: JavaObject;

    /**
     * @internal
     */
    constructor(javaObject: JavaObject) {
        this.javaObject = javaObject;
    }

    /**
     * Set Block State
     * @param pos Position
     * @param state Block State
     * @returns True If Successful
     */
    setBlockState(pos: Pos, state: BlockState): boolean {
        return useBridge('World.setBlockState', this.javaObject, pos.getX(), pos.getY(), pos.getZ(), state.javaObject) as boolean;
    }

    /**
     * Get Block State
     * @param pos Position
     * @returns Block State
     */
    getBlockState(pos: Pos): BlockState {
        const obj = useBridge('World.getBlockState', this.javaObject, pos.getX(), pos.getY(), pos.getZ()) as JavaObject;
        if (obj) {
            return new BlockState(obj);
        } else {
            return null;
        }
    }

    /**
     * Spawn Entity
     * @param id Entity ID
     * @param pos Position
     */
    spawnEntity(id: Identifier, pos: Pos): Entity {
        const obj = useBridge('World.spawnEntity', this.javaObject, pos.getX(), pos.getY(), pos.getZ(), id.toString()) as JavaObject;
        if (obj) {
            return new Entity(obj);
        } else {
            return null;
        }
    }
}